HttpDebugger class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

disable() → void
enable({String mode = 'reverse', String? upstreamBaseUrl, String? proxyBaseUrl, String proxyHttpPath = '/httpproxy', bool allowBadCertificates = false, List<Pattern>? skipPaths, List<Pattern>? skipHosts, List<String>? skipMethods, List<Pattern>? allowPaths, List<Pattern>? allowHosts, List<String>? allowMethods, List<Pattern> bypassHosts = const []}) → void
enableAuto() → void
enableForwardProxy(HttpDebuggerConfig _) → void
enableReverseProxy(HttpReverseProxyConfig _) → void
runZonedWithForwardProxy<T>(HttpDebuggerConfig _, T action()) → T
runZonedWithReverseProxy<T>(HttpReverseProxyConfig _, T action()) → T